package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.TbVipCode;

/**
 * 会员码Service接口
 *
 * @author lsm
 * @date 2023-12-22
 */
public interface ITbVipCodeService
{
    /**
     * 查询会员码
     *
     * @param codeId 会员码主键
     * @return 会员码
     */
    public TbVipCode selectTbVipCodeByCodeId(Long codeId);

    /**
     * 查询会员码列表
     *
     * @param tbVipCode 会员码
     * @return 会员码集合
     */
    public List<TbVipCode> selectTbVipCodeList(TbVipCode tbVipCode);

    /**
     * 新增会员码
     *
     * @param tbVipCode 会员码
     * @return 结果
     */
    public int insertTbVipCode(TbVipCode tbVipCode);

    /**
     * 修改会员码
     *
     * @param tbVipCode 会员码
     * @return 结果
     */
    public int updateTbVipCode(TbVipCode tbVipCode);

    /**
     * 批量删除会员码
     *
     * @param codeIds 需要删除的会员码主键集合
     * @return 结果
     */
    public int deleteTbVipCodeByCodeIds(Long[] codeIds);

    /**
     * 删除会员码信息
     *
     * @param codeId 会员码主键
     * @return 结果
     */
    public int deleteTbVipCodeByCodeId(Long codeId);


    /**
     * 生成指定数量的会员码
     * @param num 数量
     * @return 结果
     */
    public int createVipCode(Integer num);
}
